"use strict";

var _enzyme = require("enzyme");

var _react = _interopRequireDefault(require("react"));

var _menu_item = _interopRequireDefault(require("./menu_item"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var keyCodeEnter = 13;
describe('manager.ui.components.menu_item', function () {
  describe('render', function () {
    test('should use "a" tag', function () {
      var wrap = (0, _enzyme.shallow)(_react.default.createElement(_menu_item.default, {
        title: "title",
        onClick: function onClick() {
          return undefined;
        }
      }, "Content"));
      expect(wrap.matchesElement(_react.default.createElement("div", {
        role: "menuitem",
        tabIndex: "0",
        title: "title"
      }, "Content"))).toBe(true);
    });
  });
  describe('events', function () {
    var onClick;
    var wrap;
    beforeEach(function () {
      onClick = jest.fn();
      wrap = (0, _enzyme.shallow)(_react.default.createElement(_menu_item.default, {
        onClick: onClick
      }, "Content"));
    });
    test('should call onClick on a click', function () {
      wrap.simulate('click');
      expect(onClick).toHaveBeenCalled();
    });
    test('should call onClick on enter key', function () {
      var e = {
        keyCode: keyCodeEnter
      };
      wrap.simulate('keyDown', e);
      expect(onClick).toHaveBeenCalledWith(e);
    });
    test("shouldn't call onClick on other keys", function () {
      wrap.simulate('keyDown', {});
      expect(onClick).not.toHaveBeenCalled();
    });
    test('should prevent default on mousedown', function () {
      var e = {
        preventDefault: jest.fn()
      };
      wrap.simulate('mouseDown', e);
      expect(e.preventDefault).toHaveBeenCalled();
    });
  });
});